attribute highp		vec4	VertPos;

uniform		highp		mat4	WorldViewProj;
uniform		mediump	float	ContourOffset;
uniform		mediump	float	UVScale0;
uniform		highp	float	UVScale1;
uniform		highp		float	UVScale2;
uniform		highp		vec4	WarpOffset;
uniform		highp		vec4	ExtraOffset;

uniform		highp		float	WarpFactor;
uniform		highp		float	FogScale;
uniform		highp		float	FogSub;

uniform		lowp		vec4	FogColour;
uniform		lowp		vec4	SunColour;

varying		mediump	float	contourCoord;
varying		mediump	vec2	mainCoord;
varying		highp	vec2	detailCoord;
varying		highp		vec2	skyCoord;

varying		lowp		vec4	FoggedSun;
varying		lowp		vec4	AddFog;

void main(void)
{
	highp	vec2	curveOffset = VertPos.xy-WarpOffset.xy;
	highp	float co = WarpFactor*(curveOffset.x*curveOffset.x+curveOffset.y*curveOffset.y);
	
	highp vec4	warpedPos = VertPos;
//	if(warpedPos.z<0.0) warpedPos.z=0.0;
	contourCoord	= 0.6-VertPos.z*1.0/1500.0;	// should be from VertPos

	highp float fogFactor = (co-FogSub)*FogScale;

	if(warpedPos.z < 0.0)
	{
		highp vec2 wobble	= VertPos.xy*(6.28318530717959*30.0/8192.0)+ExtraOffset.xy;
		highp vec2 wobble2	= VertPos.xy*(6.28318530717959*50.0/8192.0)+ExtraOffset.zw;

		//		highp vec2 wobble2	= (VertPos.xy * (8192.0/(6.28318530717959* 3000.0)))+ExtraOffset.zw;
		
		float depth = -warpedPos.z*0.001;
		float wobScale = warpedPos.z*0.15;
		if(wobScale<-50.0) wobScale = -50.0;
		warpedPos.x += wobScale*(cos(wobble.y)*cos(wobble2.y));
		warpedPos.y += wobScale*(cos(wobble.x)*cos(wobble2.x));
		if(depth>fogFactor) fogFactor=depth;
	}
	warpedPos.z -= co;
	gl_Position		= WorldViewProj * warpedPos;
	mainCoord			= VertPos.xy * UVScale0;
	detailCoord		= VertPos.xy * UVScale1;
	skyCoord			= (VertPos.xy * UVScale2)+ExtraOffset.xy;
	
	lowp float Fog = clamp(fogFactor,0.0,1.0);
	AddFog			= FogColour*Fog;
	FoggedSun		= SunColour*((1.0-Fog));

}
