attribute highp		vec4	VertPos;
attribute lowp		vec4	VertColour;
attribute mediump vec2	VertUV;

uniform		lowp		vec4	SunColour;
uniform		lowp		vec4	AmbientColour;

uniform		highp		mat4	WorldViewProj;
uniform		highp		vec4	WarpOffset;
uniform		highp		float	WarpFactor;
uniform		highp		float	FogScale;
uniform		highp		float	FogSub;
uniform		lowp		vec4	FogColour;

varying		mediump	vec2	mainCoord;

varying		lowp		vec4	FoggedSun;
varying		lowp		vec4	AddFog;

void main(void)
{
	highp	vec2	curveOffset = VertPos.xy-WarpOffset.xy;
	
	highp vec4	warpedPos = VertPos;
	
	if(curveOffset.x> 8192.0)
	{
		curveOffset.x-=16384.0;
		warpedPos.x-=16384.0;
	}
	else if(curveOffset.x<-8192.0)
	{
		curveOffset.x+=16384.0;
		warpedPos.x+=16384.0;
	}
	if(curveOffset.y> 8192.0)
	{
		curveOffset.y-=16384.0;
		warpedPos.y-=16384.0;
	}
	else if(curveOffset.y<-8192.0)
	{
		curveOffset.y+=16384.0;
		warpedPos.y+=16384.0;
	}
	highp	float co = WarpFactor*(curveOffset.x*curveOffset.x+curveOffset.y*curveOffset.y);
	warpedPos.z -= co;
	
	lowp float Fog = clamp((co-FogSub)*FogScale,0.0,1.0);
	AddFog			= FogColour*Fog;
	FoggedSun		= VertColour*mix(AmbientColour,SunColour,VertColour.a)*(1.0-Fog);

	gl_Position		= WorldViewProj * warpedPos;
	mainCoord			= VertUV;
}
	